yakumo.nova.v2.floating_ip

Package yakumo :: Package nova :: Package v2 :: Module floating_ip |
[hide private]
[frames] | no frames]

# Module floating_ip

source code

Resource class and its manager for floating IPs in Compute API v2

Classes | [hide private]
| Resource Resource class for floating IPs in Compute API v2
| Manager Manager class for floating IPs in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('fixed_ip', 'fixed_ip', mapper.Noop), ('s
      erver', 'instance_id', mapper.Resource('nova.server')), ('ip', 'ip', m
      apper.Noop), ('pool', 'pool', mapper.Noop),]